# TropiCoders Utility Library

## Overview

`tcutils` is a Python>=3.6 library that defines code for
some common operations like path manipulation, file system operations,
packaging, configuration, schema definitions, function utilities,
YAML extensions, etc.

## Development

GitHub: https://github.com/ktomala/tcutils.git

## License

Mozilla Public License v2 (see LICENSE file).
